@@ -141,7 +141,7 @@ g_usb_device_libusb_error_to_gerror (GUsbDevice *device,
 		     "USB error on device %04x:%04x : %s [%i]",
 		     g_usb_device_get_vid (device),
 		     g_usb_device_get_pid (device),
-		     gusb_strerror (rc), rc);
+		     g_usb_strerror (rc), rc);
 
 	return FALSE;
 }
@@ -228,6 +228,34 @@ g_usb_device_close (GUsbDevice *device, GError **error)
 	return TRUE;
 }
 
+/**
+ * g_usb_device_reset:
+ * @device: a #GUsbDevice
+ * @error: a #GError, or %NULL
+ *
+ * Perform a USB port reset to reinitialize a device.
+ *
+ * If the reset succeeds, the device will appear to disconnected and reconnected.
+ * This means the @device will no longer be valid and should be closed and
+ * rediscovered.
+ *
+ * This is a blocking function which usually incurs a noticeable delay.
+ *
+ * Return value: %TRUE on success
+ **/
+gboolean
+g_usb_device_reset (GUsbDevice *device, GError **error)
+{
+	gint rc;
+	g_return_val_if_fail (G_USB_IS_DEVICE (device), FALSE);
+
+	if (device->priv->handle == NULL)
+		return g_usb_device_not_open_error (device, error);
+
+	rc = libusb_reset_device (device->priv->handle);
+	return g_usb_device_libusb_error_to_gerror (device, rc, error);
+}
+
 /**
  * g_usb_device_get_configuration:
  * @device: a #GUsbDevice
@@ -449,7 +477,8 @@ g_usb_device_sync_transfer_cb (GUsbDevice *device,
  * @request: the request field for the setup packet
  * @value: the value field for the setup packet
  * @idx: the index field for the setup packet
- * @data: a suitably-sized data buffer for either input or output
+ * @data: (array length=length): a suitably-sized data buffer for
+ * either input or output
  * @length: the length field for the setup packet.
  * @actual_length: the actual number of bytes sent, or %NULL
  * @timeout: timeout timeout (in millseconds) that this function should wait
@@ -512,7 +541,8 @@ g_usb_device_control_transfer	(GUsbDevice	*device,
  * g_usb_device_bulk_transfer:
  * @device: a #GUsbDevice
  * @endpoint: the address of a valid endpoint to communicate with
- * @data: a suitably-sized data buffer for either input or output
+ * @data: (array length=length): a suitably-sized data buffer for
+ * either input or output
  * @length: the length field for the setup packet.
  * @actual_length: the actual number of bytes sent, or %NULL
  * @timeout: timeout timeout (in millseconds) that this function should wait
@@ -565,7 +595,8 @@ g_usb_device_bulk_transfer	(GUsbDevice	*device,
  * g_usb_device_interrupt_transfer:
  * @device: a #GUsbDevice
  * @endpoint: the address of a valid endpoint to communicate with
- * @data: a suitably-sized data buffer for either input or output
+ * @data: (array length=length): a suitably-sized data buffer for
+ * either input or output
  * @length: the length field for the setup packet.
  * @actual_length: the actual number of bytes sent, or %NULL
  * @timeout: timeout timeout (in millseconds) that this function should wait
@@ -784,6 +815,12 @@ out:
 /**
  * g_usb_device_control_transfer_async:
  * @device: a #GUsbDevice
+ * @data: (array length=length): a suitably-sized data buffer for
+ * either input or output
+ * @length: the length field for the setup packet.
+ * @timeout: timeout timeout (in millseconds) that this function should wait
+ * before giving up due to no response being received. For an unlimited
+ * timeout, use 0.
  * @cancellable: a #GCancellable, or %NULL
  * @callback: the function to run on completion
  * @user_data: the data to pass to @callback
@@ -912,6 +949,13 @@ g_usb_device_bulk_transfer_finish (GUsbDevice *device,
 /**
  * g_usb_device_bulk_transfer_async:
  * @device: a #GUsbDevice instance.
+ * @endpoint: the address of a valid endpoint to communicate with
+ * @data: (array length=length): a suitably-sized data buffer for
+ * either input or output
+ * @length: the length field for the setup packet.
+ * @timeout: timeout timeout (in millseconds) that this function should wait
+ * before giving up due to no response being received. For an unlimited
+ * timeout, use 0.
  * @cancellable: a #GCancellable, or %NULL
  * @callback: the function to run on completion
  * @user_data: the data to pass to @callback
@@ -1022,6 +1066,13 @@ g_usb_device_interrupt_transfer_finish (GUsbDevice *device,
 /**
  * g_usb_device_interrupt_transfer_async:
  * @device: a #GUsbDevice instance.
+ * @endpoint: the address of a valid endpoint to communicate with
+ * @data: (array length=length): a suitably-sized data buffer for
+ * either input or output
+ * @length: the length field for the setup packet.
+ * @timeout: timeout timeout (in millseconds) that this function should wait
+ * before giving up due to no response being received. For an unlimited
+ * timeout, use 0.
  * @cancellable: a #GCancellable, or %NULL
  * @callback: the function to run on completion
  * @user_data: the data to pass to @callback
@@ -1156,7 +1207,7 @@ g_usb_device_constructor (GType			 gtype,
 	rc = libusb_get_device_descriptor (priv->device, &priv->desc);
 	if (rc != LIBUSB_SUCCESS)
 		g_warning ("Failed to get USB descriptor for device: %s",
-			   gusb_strerror (rc));
+			   g_usb_strerror (rc));
 
 	return obj;
 }
